@@ -1,6 +1,6 @@
 #!/bin/bash
 #  This script is part of Numdiff
-#  Copyright (C)  2005-2009    Ivano Primi  <ivprimi@libero.it>    
+#  Copyright (C)  2005-2012    Ivano Primi  <ivprimi@libero.it>    
 #
 #   Copying and distribution of this file, with or without modification,
 #   are permitted in any medium without royalty provided the copyright
@@ -16,7 +16,7 @@ echo "Viewer: $LESS"
 echo "Tester program: $DIFF"
 echo "Numdiff: $NUMDIFF"
 
-TESTS="test1 test2 test3 test4 test5 test6 test7 test8 test9 test10 test11 test12 test13 test14 test15 test16 test17 test18 test19 test20 test21 test22 test23"
+TESTS="test1 test2 test3 test4 test5 test6 test7 test8 test9 test10 test11 test12 test13 test14 test15 test16 test17 test18 test19 test20 test21 test22 test23 test24 test25 test26 test27 test28 test29 test30"
 
 for TEST in $TESTS
 do
